############################################################################
## Purpose: Figures for BMJ Global Health Comment entitled "The global health community at international climate change negotiations"
##
## Author: Kim Robin van Daalen
## Contact information: kim.vandaalen@bsc.es
## Date of creation: 18 March 2024 
##
## Input data: health community's attendance at COP1-28 (1995-2023)
## - Summary data by delegate type, absolute numbers 
## - Summary data by delegate type, percentage of total COP participants 
## - Summary data by UN region (Asia-Pacific States, Eastern European States, African States, Western European and other States, Latin American and Caribbean States)
## - Summary data by WB group (high-income, upper-middle-income, lower-middle-income, low-income)
## - Summary data by type of Party to the Convention (Annex I, non-Annex I)
##
############################################################################

## load packages 
library(readxl)
library(pals)
library(dplyr)
library(ggplot)
library(tidyverse)
library(patchwork)
library(MetBrewer)

############################################################################

## load data figure 1
COP_health_sum <- read_csv("Data/COP_Health_Sum.csv")
COPhealth_sum2 <- read_excel("Data/COP_Health_Sum2.xlsx")

## load data figure 2
COPhealth_sum_UN <- read_csv("Data/COPHealth_Sum_UN.csv")
COPhealth_sum_WB <- read_csv("Data/COPHealth_Sum_WB.csv")
COPhealth_sum_convention <- read.csv("Data/COPHealth_Sum_Convention.csv")

## load data figure 3
COPhealth_sum_MOH <- read_csv("Data/COPHealth_Sum_MOH.csv")
COPhealth_sum_minister <- read_csv("Data/COPHealth_Sum_Minister.csv")

############################################################################

## create figure 1A
fig1A <- COPhealth_sum %>% 
  ggplot(aes(fill=Type, y=Name, x=COP)) + 
  geom_hline(yintercept=c(250, 500, 750, 1000, 1250, 1500), linetype="dashed", size=0.1) +
  geom_bar(position="stack", stat="identity", width = 0.90) + 
  coord_flip() +
  xlab("# Conference of the Parties (COP)") +
  ylab("Sum of health actors (N)") +
  ggtitle("A. Absolute number of health actors at COPs (1995-2023)") +
  scale_x_continuous(breaks = seq(1, 28, 1)) +
  scale_y_continuous(breaks = seq(0, 2000, 250)) +
  theme_classic() +
  scale_fill_manual(values=met.brewer("Hokusai3", 11)) +
  theme(aspect.ratio=0.9,
        legend.position=c(0.7,0.4),
        legend.box="vertical",
        legend.margin=margin(),
        legend.box.margin=margin(),
        legend.text=element_text(size=8),
        legend.key.size = unit(1, 'lines'),
        axis.title.x = element_text(size = 9, face="bold"),
        axis.title.y = element_text(size = 9, face="bold"),
        axis.text.x = element_text(size = 8.5),
        axis.text.y = element_text(size = 10), 
        plot.title = element_text(size=11, face="bold"),
        legend.title = element_blank()) + 
  guides(colour = guide_legend(override.aes = list(size=3))) 

fig1A #view

## create figure 1B
fig1B <- COPhealth_sum2 %>% 
  filter(Type == "Parties & Observer States" | Type == "Observer Organisations" | Type == "Total") %>% 
  ggplot(aes(fill=Type, y=Percentage, x=COP)) + 
  geom_hline(yintercept=c(0.5, 1, 1.5, 2, 2.5, 3, 3.5), linetype="dashed", size=0.1) +
  geom_bar(position="dodge", stat="identity") + 
  coord_flip() +
  xlab("# Conference of the Parties (COP)") +
  ylab("Percentage of health actors (%)") +
  ggtitle("B. Percentage of health actors at COPs (1995-2023)") +
  scale_x_continuous(breaks = seq(1, 28, 1)) +
  scale_y_continuous(breaks = seq(0, 3.5, 0.5)) +
  theme_classic() +
  scale_fill_manual(values=met.brewer("Hokusai3", 3)) +
  theme(aspect.ratio=1.2,
        legend.position=c(0.88,0.4),
        legend.box="vertical",
        legend.margin=margin(),
        legend.box.margin=margin(),
        legend.text=element_text(size=8),
        legend.key.size = unit(1, 'lines'),
        axis.title.x = element_text(size = 9, face="bold"),
        axis.title.y = element_text(size = 9, face="bold"),
        axis.text.x = element_text(size = 8.5),
        axis.text.y = element_text(size = 10), 
        plot.title = element_text(size=11, face="bold"),
        legend.title = element_blank()) +  
  guides(colour = guide_legend(override.aes = list(size=3)))

fig1B #view

## combine fig1A and fig1B in one plot  
fig1 <- fig1A + fig2B 
fig1 #view

## save figure 1
png(file="Output/health_COP_fig1.png",
    width=1019, height=478, res=400, units="mm")
print(fig1)
dev.off()


############################################################################

## create figure 2A
fig2A <- COPhealth_sum_UN %>% 
  ggplot(aes(fill=UNGroup, y=Name, x=COP)) + 
  geom_hline(yintercept=c(50, 100, 150, 200, 250, 300, 350, 400, 450, 500, 550, 600, 650, 700), linetype="dashed", size=0.1) +
  geom_bar(position="stack", stat="identity", width = 0.90) + 
  coord_flip() +
  xlab("# Conference of the Parties (COP)") +
  ylab("Sum of health actors (N)") +
  ggtitle("A. Party & Observer State health actors by UN regional grouping") +
  scale_x_continuous(breaks = seq(1, 28, 1)) +
  scale_y_continuous(breaks = seq(0, 700, 50)) +
  theme_classic() +
  scale_fill_manual(values=met.brewer("Hokusai3", 5)) +
  theme(aspect.ratio=0.9,
        legend.position=c(0.7,0.4),
        legend.box="vertical",
        legend.margin=margin(),
        legend.box.margin=margin(),
        legend.text=element_text(size=8),
        legend.key.size = unit(1, 'lines'),
        axis.title.x = element_text(size = 9, face="bold"),
        axis.title.y = element_text(size = 9, face="bold"),
        axis.text.x = element_text(size = 8.5),
        axis.text.y = element_text(size = 10), 
        plot.title = element_text(size=11, face="bold"),
        legend.title = element_blank()) + 
  guides(colour = guide_legend(override.aes = list(size=3)))

fig2A #view

## create figure 2B
fig2B <- COPhealth_sum_WB %>% 
  ggplot(aes(fill=WBGroup, y=Name, x=COP)) + 
  geom_hline(yintercept=c(50, 100, 150, 200, 250, 300, 350, 400, 450, 500, 550, 600, 650, 700), linetype="dashed", size=0.1) +
  geom_bar(position="stack", stat="identity", width = 0.90) + 
  coord_flip() +
  xlab("# Conference of the Parties (COP)") +
  ylab("Sum of health actors (N)") +
  ggtitle("B. Party & Observer State health actors by WB income group") +
  scale_x_continuous(breaks = seq(1, 28, 1)) +
  scale_y_continuous(breaks = seq(0, 700, 50)) +
  theme_classic() +
  scale_fill_manual(values=met.brewer("Hokusai3", 5), breaks=c('High-income', 'Upper-middle income', 'Lower-middle income', 'Low-income', 'NA'), 
                    labels=c('High-income', 'Upper-middle income', 'Lower-middle income', 'Low-income', 'No classification available')) +
  theme(aspect.ratio=0.9,
        legend.position=c(0.7,0.4),
        legend.box="vertical",
        legend.margin=margin(),
        legend.box.margin=margin(),
        legend.text=element_text(size=8),
        legend.key.size = unit(1, 'lines'),
        axis.title.x = element_text(size = 9, face="bold"),
        axis.title.y = element_text(size = 9, face="bold"),
        axis.text.x = element_text(size = 8.5),
        axis.text.y = element_text(size = 10), 
        plot.title = element_text(size=11, face="bold"),
        legend.title = element_blank()) + 
  guides(colour = guide_legend(override.aes = list(size=3)))

fig2B #view

## combine fig2A and fig2B 
fig2AB <- (fig2A + fig2B) 
fig2AB #view

## save figure 2AB
png(file="Output/health_COP_fig2AB.png",
    width=1018, height=589, res=400, units="mm")
print(fig2AB)
dev.off()

## create figure 2C
fig2C <- COPhealth_sum_convention %>% 
  ggplot(aes(fill=Convention, y=Name, x=COP)) + 
  geom_hline(yintercept=c(50, 100, 150, 200, 250, 300, 350, 400, 450, 500, 550, 600, 650, 700), linetype="dashed", size=0.1) +
  geom_bar(position="stack", stat="identity", width = 0.90) + 
  coord_flip() +
  xlab("# Conference of the Parties (COP)") +
  ylab("Sum of health actors (N)") +
  ggtitle("C. Party & Observer State health actors by commitment to the Convention") +
  scale_x_continuous(breaks = seq(1, 28, 1)) +
  scale_y_continuous(breaks = seq(0, 700, 50)) +
  theme_classic() +
  scale_fill_manual(values=met.brewer("Hokusai3", 3), breaks=c('Annex 1', 'Non-Annex 1', 'NA'), 
                    labels=c('Annex 1', 'Non-Annex 1', 'No classification')) +
  theme(aspect.ratio=0.9,
        legend.position=c(0.7,0.4),
        legend.box="vertical",
        legend.margin=margin(),
        legend.box.margin=margin(),
        legend.text=element_text(size=8),
        legend.key.size = unit(1, 'lines'),
        axis.title.x = element_text(size = 9, face="bold"),
        axis.title.y = element_text(size = 9, face="bold"),
        axis.text.x = element_text(size = 8.5),
        axis.text.y = element_text(size = 10), 
        plot.title = element_text(size=11, face="bold"),
        legend.title = element_blank()) + 
  guides(colour = guide_legend(override.aes = list(size=3)))

fig2C #view 

## save figure 2C
png(file="Output/health_COP_fig2C.png",
    width=634, height=474, res=400, units="mm")
print(fig2C)
dev.off()

############################################################################

## create figure 3A 
fig3A <- COPhealth_sum_MOH
  geom_hline(yintercept=c(50, 100, 150, 200, 250, 300, 350, 400, 450, 500, 550, 600, 650, 700), linetype="dashed", size=0.1) +
  geom_bar(position="stack", stat="identity", width = 0.90) + 
  coord_flip() +
  xlab("# Conference of the Parties (COP)") +
  ylab("Sum of representatives of the Ministry of Health (N)") +
  ggtitle("A. Representatives of the Ministry of Health at COPs (1995-2023)") +
  scale_x_continuous(breaks = seq(1, 28, 1)) +
  scale_y_continuous(breaks = seq(0, 700, 50)) +
  theme_classic() +
  scale_fill_manual(values=met.brewer("Hokusai3", 3), labels=c("Other delegates", "Ministry of Health", "Ministry of Health & Environment")) +
  theme(aspect.ratio=0.9,
        legend.position=c(0.7,0.4),
        legend.box="vertical",
        legend.margin=margin(),
        legend.box.margin=margin(),
        legend.text=element_text(size=8),
        legend.key.size = unit(1, 'lines'),
        axis.title.x = element_text(size = 9, face="bold"),
        axis.title.y = element_text(size = 9, face="bold"),
        axis.text.x = element_text(size = 8.5),
        axis.text.y = element_text(size = 10), 
        plot.title = element_text(size=11, face="bold"),
        legend.title = element_blank()) + 
  guides(colour = guide_legend(override.aes = list(size=3)))

## create figure 3B
fig3B <-  COPhealth_sum_minister
    ggplot(aes(fill=MinisterHealth, y=MinisterHealth_n, x=COP)) + 
    geom_hline(yintercept=c(5, 10, 15, 20, 25, 30, 35, 40, 45, 50), linetype="dashed", size=0.1) +
    geom_bar(position="stack", stat="identity", width = 0.90) + 
    coord_flip() +
    xlab("# Conference of the Parties (COP)") +
    ylab("Sum of Ministers of Health (N)") +
    ggtitle("B. Ministers of Health at COPs (1995-2023)") +
    scale_x_continuous(breaks = seq(1, 28, 1)) +
    scale_y_continuous(breaks = seq(0, 50, 5)) +
    theme_classic() +
    scale_fill_manual(values=met.brewer("Hokusai3", 2), labels=c("Minister of Health", "Minister of Health & Environment", "Ministry of Health and Environment")) +
    theme(aspect.ratio=0.9,
          legend.position=c(0.7,0.4),
          legend.box="vertical",
          legend.margin=margin(),
          legend.box.margin=margin(),
          legend.text=element_text(size=8),
          legend.key.size = unit(1, 'lines'),
          axis.title.x = element_text(size = 9, face="bold"),
          axis.title.y = element_text(size = 9, face="bold"),
          axis.text.x = element_text(size = 8.5),
          axis.text.y = element_text(size = 10), 
          plot.title = element_text(size=11, face="bold"),
          legend.title = element_blank()) + 
    guides(colour = guide_legend(override.aes = list(size=3)))

## combine fig3A and fig3B in one plot 
fig3 <- fig3A + fig3B
fig3 #view

## save figure 3
png(file="Output/health_COP_fig3.png",
    width=1066, height=589, res=400, units="mm")
print(fig3)
dev.off()
 
############################################################################
## create supplemental figure 1
sfig1 <- COPhealth_sum2 %>% 
  filter(Type == "Total") %>% 
  ggplot(aes(fill=Type, y=TotalPax, x=COP)) + 
  geom_hline(yintercept=c(10000, 20000, 30000, 40000, 50000, 60000), linetype="dashed", size=0.1) +
  geom_bar(position="dodge", stat="identity") + 
  coord_flip() +
  xlab("# Conference of the Parties (COP)") +
  ylab("Sum of COP delegates") +
  ggtitle("Total COP delegates (1995-2023)") +
  scale_x_continuous(breaks = seq(1, 28, 1)) +
  scale_y_continuous(breaks = seq(0, 70000, 10000)) +
  theme_classic() +
  scale_fill_manual(values=met.brewer("Hokusai3", 3)) +
  theme(aspect.ratio=1.2,
        axis.title.x = element_text(size = 9, face="bold"),
        axis.title.y = element_text(size = 9, face="bold"),
        axis.text.x = element_text(size = 8.5),
        axis.text.y = element_text(size = 10), 
        plot.title = element_text(size=11, face="bold"),
        legend.position = "none") +  
  guides(colour = guide_legend(override.aes = list(size=3)))

sfig1 #view

## save supplemental figure 1
png(file="Output/health_COP_sfig1.png",
    width=434, height=517, res=400, units="mm")
print(sfg1)
dev.off()

## END 
############################################################################

